<?php
/**
 * RT Health functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package RT_Health
 */

if ( ! function_exists( 'rt_health_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function rt_health_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on RT Health, use a find and replace
		 * to change 'rt-health' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'rt-health', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_image_size( 'rt-health-blog', 358, 463, true ); 

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'rt-health' ),
			'footer-menu' => esc_html__( 'Footer Menu', 'rt-health' ),
			'social-icon' => esc_html__( 'Social Menu', 'rt-health' ),			
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'rt_health_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );
				
		// makes our theme WC compatible
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );			
	}
endif;
add_action( 'after_setup_theme', 'rt_health_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function rt_health_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'rt_health_content_width', 640 );
}
add_action( 'after_setup_theme', 'rt_health_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function rt_health_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'rt-health' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'rt-health' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		/* translators: Footer Number. */
		'name'          => esc_html__( 'Footer Map', 'rt-health' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Enter your google map address here.', 'rt-health' ),
		'before_widget' => '<aside id="%1$s" class="%2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</h2></span>',
	) );
	register_sidebar( array(
		/* translators: Footer Number. */
		'name'          => sprintf( esc_html__( 'Footer %d', 'rt-health' ), 2 ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</h2></span>',
	) );
	register_sidebar( array(
		/* translators: Footer Number. */
		'name'          => sprintf( esc_html__( 'Footer %d', 'rt-health' ), 3 ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</h2></span>',
	) );	

	if ( rt_health_is_woocommerce_active() ):
		register_sidebar( array(
			'name'          => esc_html__( 'Shop Sidebar', 'rt-health' ),
			'id'            => 'shop-sidebar',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="widget-title"><span>',
			'after_title'   => '</h2></span>',
		) );

	endif;	
}
add_action( 'widgets_init', 'rt_health_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function rt_health_scripts() {

	wp_enqueue_style( 'rt-health-fonts', rt_health_fonts_url(), array(), null );	

	wp_enqueue_style( 'font-awesome', get_template_directory_uri() .'/assets/css/font-awesome.min.css');

	wp_enqueue_style( 'JQuery-ui-css', get_template_directory_uri() . '/assets/css/jQuery-ui.css' );

	wp_enqueue_style( 'meanmenu-css', get_template_directory_uri() . '/assets/css/meanmenu.css' );

	wp_enqueue_style( 'magnific-popup-css', get_template_directory_uri() .'/assets/css/magnific-popup.css' );

	wp_enqueue_style( 'jquery-mCustomScrollbar-css', get_template_directory_uri() .'/assets/css/jquery.mCustomScrollbar.min.css' );

	wp_enqueue_style( 'rt-health-style', get_stylesheet_uri() );

	wp_enqueue_style( 'rt-health-responsive', get_template_directory_uri() .'/assets/css/responsive.css' );

	wp_enqueue_script( 'jquery-meanenu-js', get_template_directory_uri() .'/assets/js/jquery.meanmenu.js', array( 'jquery'), 'v2.0.8', true );

	wp_enqueue_script( 'ResizeSensor-js', get_template_directory_uri() .'/assets/js/ResizeSensor.js', array(), 'v2.0.8', true );

	wp_enqueue_script( 'theia-sticky-sidebar-js', get_template_directory_uri() .'/assets/js/theia-sticky-sidebar.js', array(), 'v1.7.0', true );


	wp_enqueue_script( 'jquery.magnific-popup.js', get_template_directory_uri() .'/assets/js/jquery.magnific-popup.js', array( 'jquery' ), 'v2.0.8', true );

	wp_enqueue_script( 'jquery-ui-js', get_template_directory_uri() .'/assets/js/jquery-ui.js', array( 'jquery' ), 'v1.12.1', true );

	wp_enqueue_script( 'jquery-mCustomScrollbar-concat-js', get_template_directory_uri() .'/assets/js/jquery.mCustomScrollbar.concat.min.js', array( 'jquery' ), '3.1.13', true );

	wp_enqueue_script( 'rt-health-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'rt-health-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script( 'rt-health-custom', get_template_directory_uri() . '/assets/js/custom.js', array(), '1.0.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'rt_health_scripts' );

/**
 * Load init.
 */
require_once trailingslashit( get_template_directory() ) . 'inc/init.php';
